# I am a `snek5000` user should I use this?

No.

# What is this anyway?

Requirements files with dependencies pinned for docs, testing and development.

# Who is this meant for?

CI servers and developers.

# How should I use this?

Run:

```sh
make list-sessions
```
